Interface BridgeBlindTransfer

All Superinterfaces:
Event, Message

public interface BridgeBlindTransfer extends Event
Generated by: JavaInterface
  • Method Details

    • getResult

      String getResult()
      The result of the transfer attempt
      Returns:
      String
      Since:
      ARI_1_1_0
    • getTransferee

      Channel getTransferee()
      The channel that is being transferred
      Returns:
      Channel
      Since:
      ARI_1_5_0
    • setExten

      void setExten(String val)
      Parameters:
      val - The extension transferred to
      Since:
      ARI_1_1_0
    • setContext

      void setContext(String val)
      Parameters:
      val - The context transferred to
      Since:
      ARI_1_1_0
    • getBridge

      Bridge getBridge()
      The bridge being transferred
      Returns:
      Bridge
      Since:
      ARI_1_1_0
    • setReplace_channel

      void setReplace_channel(Channel val)
      Parameters:
      val - The channel that is replacing transferer when the transferee(s) can not be transferred directly
      Since:
      ARI_1_5_0
    • getContext

      String getContext()
      The context transferred to
      Returns:
      String
      Since:
      ARI_1_1_0
    • getReplace_channel

      Channel getReplace_channel()
      The channel that is replacing transferer when the transferee(s) can not be transferred directly
      Returns:
      Channel
      Since:
      ARI_1_5_0
    • getChannel

      Channel getChannel()
      The channel performing the blind transfer
      Returns:
      Channel
      Since:
      ARI_1_1_0
    • setIs_external

      void setIs_external(Boolean val)
      Parameters:
      val - Whether the transfer was externally initiated or not
      Since:
      ARI_1_1_0
    • setChannel

      void setChannel(Channel val)
      Parameters:
      val - The channel performing the blind transfer
      Since:
      ARI_1_1_0
    • setBridge

      void setBridge(Bridge val)
      Parameters:
      val - The bridge being transferred
      Since:
      ARI_1_1_0
    • setTransferee

      void setTransferee(Channel val)
      Parameters:
      val - The channel that is being transferred
      Since:
      ARI_1_5_0
    • setResult

      void setResult(String val)
      Parameters:
      val - The result of the transfer attempt
      Since:
      ARI_1_1_0
    • getIs_external

      Boolean getIs_external()
      Whether the transfer was externally initiated or not
      Returns:
      Boolean
      Since:
      ARI_1_1_0
    • getExten

      String getExten()
      The extension transferred to
      Returns:
      String
      Since:
      ARI_1_1_0