Interface Message
-
- All Known Subinterfaces:
ApplicationMoveFailed,ApplicationReplaced,BridgeAttendedTransfer,BridgeBlindTransfer,BridgeCreated,BridgeDestroyed,BridgeMerged,BridgeVideoSourceChanged,ChannelCallerId,ChannelConnectedLine,ChannelCreated,ChannelDestroyed,ChannelDialplan,ChannelDtmfReceived,ChannelEnteredBridge,ChannelHangupRequest,ChannelHold,ChannelLeftBridge,ChannelStateChange,ChannelTalkingFinished,ChannelTalkingStarted,ChannelUnhold,ChannelUserevent,ChannelVarset,ContactStatusChange,DeviceStateChanged,Dial,EndpointStateChange,Event,MissingParams,PeerStatusChange,PlaybackContinuing,PlaybackFinished,PlaybackStarted,RecordingFailed,RecordingFinished,RecordingStarted,StasisEnd,StasisStart,TextMessageReceived
- All Known Implementing Classes:
MessageQueue.ErrorMessage
public interface MessageGenerated by: JavaInterface
-
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description java.lang.StringgetAsterisk_id()The unique ID for the Asterisk instance that raised this event.java.lang.StringgetType()Indicates the type of this message.voidsetAsterisk_id(java.lang.String val)voidsetType(java.lang.String val)
-
-
-
Method Detail
-
setAsterisk_id
void setAsterisk_id(java.lang.String val)
- Parameters:
val- The unique ID for the Asterisk instance that raised this event.- Since:
- ARI_1_10_0
-
getType
java.lang.String getType()
Indicates the type of this message.- Returns:
- String
- Since:
- ARI_0_0_1
-
getAsterisk_id
java.lang.String getAsterisk_id()
The unique ID for the Asterisk instance that raised this event.- Returns:
- String
- Since:
- ARI_1_10_0
-
setType
void setType(java.lang.String val)
- Parameters:
val- Indicates the type of this message.- Since:
- ARI_0_0_1
-
-