Interface Peer


public interface Peer
Generated by: JavaInterface
  • Method Details

    • getCause

      String getCause()
      An optional reason associated with the change in peer_status.
      Returns:
      String
      Since:
      ARI_1_9_0
    • getPeer_status

      String getPeer_status()
      The current state of the peer. Note that the values of the status are dependent on the underlying peer technology.
      Returns:
      String
      Since:
      ARI_1_9_0
    • getTime

      String getTime()
      The last known time the peer was contacted.
      Returns:
      String
      Since:
      ARI_1_9_0
    • getAddress

      String getAddress()
      The IP address of the peer.
      Returns:
      String
      Since:
      ARI_1_9_0
    • setAddress

      void setAddress(String val)
      Parameters:
      val - The IP address of the peer.
      Since:
      ARI_1_9_0
    • setPeer_status

      void setPeer_status(String val)
      Parameters:
      val - The current state of the peer. Note that the values of the status are dependent on the underlying peer technology.
      Since:
      ARI_1_9_0
    • getPort

      String getPort()
      The port of the peer.
      Returns:
      String
      Since:
      ARI_1_9_0
    • setPort

      void setPort(String val)
      Parameters:
      val - The port of the peer.
      Since:
      ARI_1_9_0
    • setTime

      void setTime(String val)
      Parameters:
      val - The last known time the peer was contacted.
      Since:
      ARI_1_9_0
    • setCause

      void setCause(String val)
      Parameters:
      val - An optional reason associated with the change in peer_status.
      Since:
      ARI_1_9_0