Interface TextMessage


public interface TextMessage
Generated by: JavaInterface
  • Method Details

    • setBody

      void setBody(String val)
      Parameters:
      val - The text of the message.
      Since:
      ARI_1_5_0
    • setVariables

      void setVariables(Object val)
      Parameters:
      val - Technology specific key/value pairs (JSON object) associated with the message.
      Since:
      ARI_1_11_2
    • getVariablesList

      List<TextMessageVariable> getVariablesList()
      Technology specific key/value pairs associated with the message.
      Returns:
      List>TextMessageVariable<
      Since:
      ARI_1_5_0
    • getBody

      String getBody()
      The text of the message.
      Returns:
      String
      Since:
      ARI_1_5_0
    • setTo

      void setTo(String val)
      Parameters:
      val - A technology specific URI specifying the destination of the message. Valid technologies include sip, pjsip, and xmp. The destination of a message should be an endpoint.
      Since:
      ARI_1_5_0
    • setFrom

      void setFrom(String val)
      Parameters:
      val - A technology specific URI specifying the source of the message. For sip and pjsip technologies, any SIP URI can be specified. For xmpp, the URI must correspond to the client connection being used to send the message.
      Since:
      ARI_1_5_0
    • getTo

      String getTo()
      A technology specific URI specifying the destination of the message. Valid technologies include sip, pjsip, and xmp. The destination of a message should be an endpoint.
      Returns:
      String
      Since:
      ARI_1_5_0
    • setVariablesList

      void setVariablesList(List<TextMessageVariable> val)
      Parameters:
      val - Technology specific key/value pairs associated with the message.
      Since:
      ARI_1_5_0
    • getFrom

      String getFrom()
      A technology specific URI specifying the source of the message. For sip and pjsip technologies, any SIP URI can be specified. For xmpp, the URI must correspond to the client connection being used to send the message.
      Returns:
      String
      Since:
      ARI_1_5_0
    • getVariables

      Object getVariables()
      Technology specific key/value pairs (JSON object) associated with the message.
      Returns:
      Object
      Since:
      ARI_1_11_2