Package ch.loway.oss.ari4java.tools
Enum AriConnectionEvent
- java.lang.Object
-
- java.lang.Enum<AriConnectionEvent>
-
- ch.loway.oss.ari4java.tools.AriConnectionEvent
-
- All Implemented Interfaces:
java.io.Serializable,java.lang.Comparable<AriConnectionEvent>
public enum AriConnectionEvent extends java.lang.Enum<AriConnectionEvent>
-
-
Enum Constant Summary
Enum Constants Enum Constant Description WS_CONNECTEDWS_DISCONNECTED
-
Method Summary
All Methods Static Methods Concrete Methods Modifier and Type Method Description static AriConnectionEventvalueOf(java.lang.String name)Returns the enum constant of this type with the specified name.static AriConnectionEvent[]values()Returns an array containing the constants of this enum type, in the order they are declared.
-
-
-
Enum Constant Detail
-
WS_CONNECTED
public static final AriConnectionEvent WS_CONNECTED
-
WS_DISCONNECTED
public static final AriConnectionEvent WS_DISCONNECTED
-
-
Method Detail
-
values
public static AriConnectionEvent[] values()
Returns an array containing the constants of this enum type, in the order they are declared. This method may be used to iterate over the constants as follows:for (AriConnectionEvent c : AriConnectionEvent.values()) System.out.println(c);
- Returns:
- an array containing the constants of this enum type, in the order they are declared
-
valueOf
public static AriConnectionEvent valueOf(java.lang.String name)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
java.lang.IllegalArgumentException- if this enum type has no constant with the specified namejava.lang.NullPointerException- if the argument is null
-
-