Interface ActionEndpoints
public interface ActionEndpoints
Generated by: JavaInterface
-
Method Summary
Modifier and TypeMethodDescriptionch.loway.oss.ari4java.generated.actions.requests.EndpointsGetRequestget()Details for an endpoint.ch.loway.oss.ari4java.generated.actions.requests.EndpointsListGetRequestlist()List all endpoints.ch.loway.oss.ari4java.generated.actions.requests.EndpointsListByTechGetRequestList available endoints for a given endpoint technology.ch.loway.oss.ari4java.generated.actions.requests.EndpointsReferPostRequestRefer an endpoint or technology URI to some technology URI or endpoint.ch.loway.oss.ari4java.generated.actions.requests.EndpointsReferToEndpointPostRequestreferToEndpoint(String from, String refer_to) Refer an endpoint or technology URI to some technology URI or endpoint.ch.loway.oss.ari4java.generated.actions.requests.EndpointsSendMessagePutRequestsendMessage(String to, String from) Send a message to some technology URI or endpoint.ch.loway.oss.ari4java.generated.actions.requests.EndpointsSendMessageToEndpointPutRequestsendMessageToEndpoint(String from) Send a message to some endpoint in a technology.
-
Method Details
-
sendMessageToEndpoint
ch.loway.oss.ari4java.generated.actions.requests.EndpointsSendMessageToEndpointPutRequest sendMessageToEndpoint(String from) throws RestException Send a message to some endpoint in a technology.- Parameters:
from- The endpoint resource or technology specific identity to send this message from. Valid resources are sip, pjsip, and xmpp.- Returns:
- EndpointsSendMessageToEndpointPutRequest
- Throws:
RestException- an error- Since:
- ARI_1_5_0
-
list
ch.loway.oss.ari4java.generated.actions.requests.EndpointsListGetRequest list() throws RestExceptionList all endpoints.- Returns:
- EndpointsListGetRequest
- Throws:
RestException- an error- Since:
- ARI_0_0_1
-
listByTech
ch.loway.oss.ari4java.generated.actions.requests.EndpointsListByTechGetRequest listByTech() throws RestExceptionList available endoints for a given endpoint technology.- Returns:
- EndpointsListByTechGetRequest
- Throws:
RestException- an error- Since:
- ARI_0_0_1
-
referToEndpoint
ch.loway.oss.ari4java.generated.actions.requests.EndpointsReferToEndpointPostRequest referToEndpoint(String from, String refer_to) throws RestException Refer an endpoint or technology URI to some technology URI or endpoint.- Parameters:
from- The endpoint resource or technology specific identity to refer from.refer_to- The endpoint resource or technology specific URI to refer to.- Returns:
- EndpointsReferToEndpointPostRequest
- Throws:
RestException- an error- Since:
- ARI_6_0_1
-
refer
ch.loway.oss.ari4java.generated.actions.requests.EndpointsReferPostRequest refer(String to, String from, String refer_to) throws RestException Refer an endpoint or technology URI to some technology URI or endpoint.- Parameters:
to- The endpoint resource or technology specific URI that should be referred to somewhere. Valid resource is pjsip.from- The endpoint resource or technology specific identity to refer from.refer_to- The endpoint resource or technology specific URI to refer to.- Returns:
- EndpointsReferPostRequest
- Throws:
RestException- an error- Since:
- ARI_6_0_1
-
get
Details for an endpoint.- Returns:
- EndpointsGetRequest
- Throws:
RestException- an error- Since:
- ARI_0_0_1
-
sendMessage
ch.loway.oss.ari4java.generated.actions.requests.EndpointsSendMessagePutRequest sendMessage(String to, String from) throws RestException Send a message to some technology URI or endpoint.- Parameters:
to- The endpoint resource or technology specific URI to send the message to. Valid resources are sip, pjsip, and xmpp.from- The endpoint resource or technology specific identity to send this message from. Valid resources are sip, pjsip, and xmpp.- Returns:
- EndpointsSendMessagePutRequest
- Throws:
RestException- an error- Since:
- ARI_1_5_0
-