Interface BridgeBlindTransfer
Generated by: JavaInterface
-
Method Summary
Modifier and TypeMethodDescriptionThe bridge being transferredThe channel performing the blind transferThe context transferred togetExten()The extension transferred toWhether the transfer was externally initiated or notThe channel that is replacing transferer when the transferee(s) can not be transferred directlyThe result of the transfer attemptThe channel that is being transferredvoidvoidsetChannel(Channel val) voidsetContext(String val) voidvoidsetIs_external(Boolean val) voidvoidvoidsetTransferee(Channel val) Methods inherited from interface ch.loway.oss.ari4java.generated.models.Event
getApplication, getTimestamp, setApplication, setTimestampMethods inherited from interface ch.loway.oss.ari4java.generated.models.Message
getAsterisk_id, getType, setAsterisk_id, setType
-
Method Details
-
getResult
String getResult()The result of the transfer attempt- Returns:
- String
- Since:
- ARI_1_1_0
-
getTransferee
Channel getTransferee()The channel that is being transferred- Returns:
- Channel
- Since:
- ARI_1_5_0
-
setExten
- Parameters:
val- The extension transferred to- Since:
- ARI_1_1_0
-
setContext
- Parameters:
val- The context transferred to- Since:
- ARI_1_1_0
-
getBridge
Bridge getBridge()The bridge being transferred- Returns:
- Bridge
- Since:
- ARI_1_1_0
-
setReplace_channel
- Parameters:
val- The channel that is replacing transferer when the transferee(s) can not be transferred directly- Since:
- ARI_1_5_0
-
getContext
String getContext()The context transferred to- Returns:
- String
- Since:
- ARI_1_1_0
-
getReplace_channel
Channel getReplace_channel()The channel that is replacing transferer when the transferee(s) can not be transferred directly- Returns:
- Channel
- Since:
- ARI_1_5_0
-
getChannel
Channel getChannel()The channel performing the blind transfer- Returns:
- Channel
- Since:
- ARI_1_1_0
-
setIs_external
- Parameters:
val- Whether the transfer was externally initiated or not- Since:
- ARI_1_1_0
-
setChannel
- Parameters:
val- The channel performing the blind transfer- Since:
- ARI_1_1_0
-
setBridge
- Parameters:
val- The bridge being transferred- Since:
- ARI_1_1_0
-
setTransferee
- Parameters:
val- The channel that is being transferred- Since:
- ARI_1_5_0
-
setResult
- Parameters:
val- The result of the transfer attempt- Since:
- ARI_1_1_0
-
getIs_external
Boolean getIs_external()Whether the transfer was externally initiated or not- Returns:
- Boolean
- Since:
- ARI_1_1_0
-
getExten
String getExten()The extension transferred to- Returns:
- String
- Since:
- ARI_1_1_0
-