Interface Channel
- All Superinterfaces:
EventSource
Generated by: JavaInterface
-
Method Summary
Modifier and TypeMethodDescriptionThe Caller ID RDNISChannel variablesTimestamp when channel was createdCurrent location in the dialplangetId()Unique identifier of the channel.The default spoken languagegetName()Name of the channel (i.e.Protocol id from underlying channel driver (i.e.getState()The Tenant ID for the channelvoidsetAccountcode(String val) voidvoidsetCaller_rdnis(String val) voidsetChannelvars(Object val) voidsetConnected(CallerID val) voidsetCreationtime(Date val) voidsetDialplan(DialplanCEP val) voidvoidsetLanguage(String val) voidvoidsetProtocol_id(String val) voidvoidsetTenantid(String val)
-
Method Details
-
setProtocol_id
- Parameters:
val- Protocol id from underlying channel driver (i.e. Call-ID for chan_sip/chan_pjsip; will be empty if not applicable or not implemented by driver).- Since:
- ARI_4_1_4
-
getLanguage
String getLanguage()The default spoken language- Returns:
- String
- Since:
- ARI_1_6_0
-
getCaller_rdnis
String getCaller_rdnis()The Caller ID RDNIS- Returns:
- String
- Since:
- ARI_6_0_1
-
getCaller
CallerID getCaller()- Returns:
- CallerID
- Since:
- ARI_0_0_1
-
setAccountcode
- Parameters:
val- the value- Since:
- ARI_0_0_1
-
setCaller
- Parameters:
val- the value- Since:
- ARI_0_0_1
-
setCreationtime
- Parameters:
val- Timestamp when channel was created- Since:
- ARI_0_0_1
-
getAccountcode
String getAccountcode()- Returns:
- String
- Since:
- ARI_0_0_1
-
getState
String getState()- Returns:
- String
- Since:
- ARI_0_0_1
-
setConnected
- Parameters:
val- the value- Since:
- ARI_0_0_1
-
setCaller_rdnis
- Parameters:
val- The Caller ID RDNIS- Since:
- ARI_6_0_1
-
setTenantid
- Parameters:
val- The Tenant ID for the channel- Since:
- ARI_6_0_0
-
setName
- Parameters:
val- Name of the channel (i.e. SIP/foo-0000a7e3)- Since:
- ARI_0_0_1
-
getCreationtime
Date getCreationtime()Timestamp when channel was created- Returns:
- Date
- Since:
- ARI_0_0_1
-
getName
String getName()Name of the channel (i.e. SIP/foo-0000a7e3)- Returns:
- String
- Since:
- ARI_0_0_1
-
getDialplan
DialplanCEP getDialplan()Current location in the dialplan- Returns:
- DialplanCEP
- Since:
- ARI_0_0_1
-
getTenantid
String getTenantid()The Tenant ID for the channel- Returns:
- String
- Since:
- ARI_6_0_0
-
setDialplan
- Parameters:
val- Current location in the dialplan- Since:
- ARI_0_0_1
-
getProtocol_id
String getProtocol_id()Protocol id from underlying channel driver (i.e. Call-ID for chan_sip/chan_pjsip; will be empty if not applicable or not implemented by driver).- Returns:
- String
- Since:
- ARI_4_1_4
-
setState
- Parameters:
val- the value- Since:
- ARI_0_0_1
-
getConnected
CallerID getConnected()- Returns:
- CallerID
- Since:
- ARI_0_0_1
-
setLanguage
- Parameters:
val- The default spoken language- Since:
- ARI_1_6_0
-
getChannelvars
Object getChannelvars()Channel variables- Returns:
- Object
- Since:
- ARI_2_0_0
-
setChannelvars
- Parameters:
val- Channel variables- Since:
- ARI_2_0_0
-
setId
- Parameters:
val- Unique identifier of the channel. This is the same as the Uniqueid field in AMI.- Since:
- ARI_0_0_1
-
getId
String getId()Unique identifier of the channel. This is the same as the Uniqueid field in AMI.- Returns:
- String
- Since:
- ARI_0_0_1
-